@@ -71,44 +71,43 @@ class TestMain(unittest.TestCase):
     def test_get_config(self):
         # testing with assets dir,have 2 config files
         mock_configs = clickgen.get_configs(
-            dir=self.mock_config_dir_with_configs)
+            directory=self.mock_config_dir_with_configs)
         self.assertEqual(len(mock_configs), 2)
 
         # testing with empty dir
         mock_configs = clickgen.get_configs(
-            dir=self.mock_config_dir_with_out_configs)
+            directory=self.mock_config_dir_with_out_configs)
         self.assertEqual(len(mock_configs), 0)
 
     def test_is_animated(self):
         # testing config file with aimation
         self.assertTrue(
             clickgen.is_animated(
-                config=assets.get_animated_mock_config_path()))
+                config=assets.animated_mock_config_path))
 
         # testing config file without aimation
         self.assertFalse(
-            clickgen.is_animated(config=assets.get_static_mock_config_path()))
+            clickgen.is_animated(config=assets.static_mock_config_path))
 
     def test_get_cur_name(self):
         # window extensions
-        self.assert_cur_name(config=assets.get_animated_mock_config_path(),
+        self.assert_cur_name(config=assets.animated_mock_config_path,
                              type='win',
                              expect_ext='mock_animated.ani')
-        self.assert_cur_name(config=assets.get_static_mock_config_path(),
+        self.assert_cur_name(config=assets.static_mock_config_path,
                              type='win',
                              expect_ext='mock_static.cur')
 
         # x11 extensions
-        self.assert_cur_name(config=assets.get_animated_mock_config_path(),
+        self.assert_cur_name(config=assets.animated_mock_config_path,
                              type='x11',
                              expect_ext='mock_animated')
-        self.assert_cur_name(config=assets.get_static_mock_config_path(),
+        self.assert_cur_name(config=assets.static_mock_config_path,
                              type='x11',
                              expect_ext='mock_static')
 
     def test_x11_dir_struc(self):
         # testing x11 with directory
-        print('\n🧪 Testing x11 directory Structure')
         clickgen.main(name=self.mock_name,
                       config_dir=self.mock_config_path,
                       out_path=self.mock_out_path,
@@ -118,7 +117,6 @@ class TestMain(unittest.TestCase):
 
     def test_win_dir_struc(self):
         # testing win with directory
-        print('\n🧪 Testing win directory Structure')
         clickgen.main(name=self.mock_name,
                       config_dir=self.mock_config_path,
                       out_path=self.mock_out_path,
@@ -127,7 +125,6 @@ class TestMain(unittest.TestCase):
         self.assert_win_dir()
 
     def test_dir_struc(self):
-        print('\n🧪 Testing all directory Structure')
         clickgen.main(name=self.mock_name,
                       config_dir=self.mock_config_path,
                       out_path=self.mock_out_path,
@@ -138,8 +135,6 @@ class TestMain(unittest.TestCase):
         self.assert_x11_dir()
 
     def test_archive(self):
-
-        print('\n🧪 Testing archive')
         clickgen.main(name=self.mock_name,
                       config_dir=self.mock_config_path,
                       out_path=self.mock_out_path,
@@ -154,4 +149,4 @@ class TestMain(unittest.TestCase):
 
 
 if __name__ == "__main__":
-    unittest.main()
\ No newline at end of file
+    unittest.main()
